@@ -15,12 +15,12 @@
 	elseif (isset($_REQUEST['view']))
 		$tableName =& $_REQUEST['view'];
 	else 
-		die("No table provided!");
+		die($lang['strnotableprovided']);
 
 	/**
 	 * Displays a screen where they can alter a column
 	 */
-	function doProperties($msg = '') {
+	function doAlter($msg = '') {
 		global $data, $misc, $_reload_browser;
 		global $lang;
 
@@ -28,99 +28,98 @@
 
 		switch ($_REQUEST['stage']) {
 			case 1:
-				global $lang;
-
 				$misc->printTrail('column');
-				$misc->printTitle($lang['straltercolumn'], 'pg.column.alter'); 
+				$misc->printTitle($lang['stralter'], 'pg.column.alter'); 
 				$misc->printMsg($msg);
 
+				echo "<script src=\"tables.js\" type=\"text/javascript\"></script>";
 				echo "<form action=\"colproperties.php\" method=\"post\">\n";
 
 				// Output table header
 				echo "<table>\n";
-				echo "<tr><th class=\"data required\">{$lang['strname']}</th>";
+				echo "<tr><th class=\"data required\">{$lang['strname']}</th>\n";
 				if ($data->hasAlterColumnType()) {
-					echo "<th class=\"data required\" colspan=\"2\">{$lang['strtype']}</th>";
-					echo "<th class=\"data\">{$lang['strlength']}</th>";
+					echo "<th class=\"data required\" colspan=\"2\">{$lang['strtype']}</th>\n";
+					echo "<th class=\"data\">{$lang['strlength']}</th>\n";
 				}
 				else {
-					echo "<th class=\"data required\">{$lang['strtype']}</th>";					
+					echo "<th class=\"data required\">{$lang['strtype']}</th>\n";
 				}
-				echo "<th class=\"data\">{$lang['strnotnull']}</th><th class=\"data\">{$lang['strdefault']}</th><th class=\"data\">{$lang['strcomment']}</th></tr>";
+				echo "<th class=\"data\">{$lang['strnotnull']}</th>\n<th class=\"data\">{$lang['strdefault']}</th>\n<th class=\"data\">{$lang['strcomment']}</th></tr>\n";
 
 				$column = $data->getTableAttributes($_REQUEST['table'], $_REQUEST['column']);
-				$column->f['attnotnull'] = $data->phpBool($column->f['attnotnull']);
+				$column->fields['attnotnull'] = $data->phpBool($column->fields['attnotnull']);
 
 				// Upon first drawing the screen, load the existing column information
 				// from the database.
 				if (!isset($_REQUEST['default'])) {
-					$_REQUEST['field'] = $column->f['attname'];
-					$_REQUEST['type'] = $column->f['base_type'];
+					$_REQUEST['field'] = $column->fields['attname'];
+					$_REQUEST['type'] = $column->fields['base_type'];
 					// Check to see if its' an array type...
 					// XXX: HACKY
-					if (substr($column->f['base_type'], strlen($column->f['base_type']) - 2) == '[]') {
-						$_REQUEST['type'] = substr($column->f['base_type'], 0, strlen($column->f['base_type']) - 2);
+					if (substr($column->fields['base_type'], strlen($column->fields['base_type']) - 2) == '[]') {
+						$_REQUEST['type'] = substr($column->fields['base_type'], 0, strlen($column->fields['base_type']) - 2);
 						$_REQUEST['array'] = '[]';
 					}
 					else {
-						$_REQUEST['type'] = $column->f['base_type'];
+						$_REQUEST['type'] = $column->fields['base_type'];
 						$_REQUEST['array'] = '';
 					}
 					// To figure out the length, look in the brackets :(
 					// XXX: HACKY
-					if ($column->f['type'] != $column->f['base_type'] && ereg('\\(([0-9, ]*)\\)', $column->f['type'], $bits)) {
+					if ($column->fields['type'] != $column->fields['base_type'] && preg_match('/\\(([0-9, ]*)\\)/', $column->fields['type'], $bits)) {
 						$_REQUEST['length'] = $bits[1];
 					}
 					else
 						$_REQUEST['length'] = '';
-					$_REQUEST['default'] = $_REQUEST['olddefault'] = $column->f['adsrc'];
-					if ($column->f['attnotnull']) $_REQUEST['notnull'] = 'YES';
-					$_REQUEST['comment'] = $column->f['comment'];
+					$_REQUEST['default'] = $_REQUEST['olddefault'] = $column->fields['adsrc'];
+					if ($column->fields['attnotnull']) $_REQUEST['notnull'] = 'YES';
+					$_REQUEST['comment'] = $column->fields['comment'];
 				}				
 
 				// Column name
-				echo "<tr><td><input name=\"field\" size=\"32\" value=\"",
-					htmlspecialchars($_REQUEST['field']), "\" /></td>";
+				echo "<tr><td><input name=\"field\" size=\"16\" maxlength=\"{$data->_maxNameLen}\" value=\"",
+					htmlspecialchars($_REQUEST['field']), "\" /></td>\n";
 					
 				// Column type
+				$escaped_predef_types = array(); // the JS escaped array elements
 				if ($data->hasAlterColumnType()) {
 					// Fetch all available types
 					$types = $data->getTypes(true, false, true);
+					$types_for_js = array();
 					
-					echo "<td><select name=\"type\">\n";				
-					// Output any "magic" types.  This came in with Alter Column Type so we don't need to check that
-					foreach ($data->extraTypes as $v) {
-						echo "<option value=\"", htmlspecialchars($v), "\"",
-						($v == $_REQUEST['type']) ? ' selected="selected"' : '', ">",
-							$misc->printVal($v), "</option>\n";
-					}
+					echo "<td><select name=\"type\" id=\"type\" onchange=\"checkLengths(document.getElementById('type').value,'');\">\n";				
 					while (!$types->EOF) {
-						$typname = $types->f['typname'];
-						echo "<option value=\"", htmlspecialchars($typname), "\"", ($typname == $_REQUEST['type']) ? ' selected="selected"' : '', ">",
+						$typname = $types->fields['typname'];
+						$types_for_js[] = $typname;
+						echo "\t<option value=\"", htmlspecialchars($typname), "\"", ($typname == $_REQUEST['type']) ? ' selected="selected"' : '', ">",
 							$misc->printVal($typname), "</option>\n";
 						$types->moveNext();
 					}
-					echo "</select></td>";
+					echo "</select></td>\n";
 					
 					// Output array type selector
 					echo "<td><select name=\"array\">\n";
-					echo "<option value=\"\"", ($_REQUEST['array'] == '') ? ' selected="selected"' : '', "></option>\n";
-					echo "<option value=\"[]\"", ($_REQUEST['array'] == '[]') ? ' selected="selected"' : '', ">[ ]</option>\n";
+					echo "\t<option value=\"\"", ($_REQUEST['array'] == '') ? ' selected="selected"' : '', "></option>\n";
+					echo "\t<option value=\"[]\"", ($_REQUEST['array'] == '[]') ? ' selected="selected"' : '', ">[ ]</option>\n";
 					echo "</select></td>\n";
+					$predefined_size_types = array_intersect($data->predefined_size_types, $types_for_js);
+					foreach($predefined_size_types as $value) {
+						$escaped_predef_types[] = "'{$value}'";
+					}
 	
-					echo "<td><input name=\"length\" size=\"8\" value=\"",
-						htmlspecialchars($_REQUEST['length']), "\" /></td>";
+					echo "<td><input name=\"length\" id=\"lengths\" size=\"8\" value=\"",
+						htmlspecialchars($_REQUEST['length']), "\" /></td>\n";
 				} else {
 					// Otherwise draw the read-only type name
-					echo "<td>", $misc->printVal($data->formatType($column->f['type'], $column->f['atttypmod'])), "</td>";
+					echo "<td>", $misc->printVal($data->formatType($column->fields['type'], $column->fields['atttypmod'])), "</td>\n";
 				}
 				
 				echo "<td><input type=\"checkbox\" name=\"notnull\"", (isset($_REQUEST['notnull'])) ? ' checked="checked"' : '', " /></td>\n";
 				echo "<td><input name=\"default\" size=\"20\" value=\"", 
-					htmlspecialchars($_REQUEST['default']), "\" /></td>";
-				echo "<td><input name=\"comment\" size=\"20\" value=\"", 
-					htmlspecialchars($_REQUEST['comment']), "\" /></td>";
-				
+					htmlspecialchars($_REQUEST['default']), "\" /></td>\n";
+				echo "<td><input name=\"comment\" size=\"40\" value=\"", 
+					htmlspecialchars($_REQUEST['comment']), "\" /></td></tr>\n";
 				echo "</table>\n";
 				echo "<p><input type=\"hidden\" name=\"action\" value=\"properties\" />\n";
 				echo "<input type=\"hidden\" name=\"stage\" value=\"2\" />\n";
@@ -128,8 +127,8 @@
 				echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
 				echo "<input type=\"hidden\" name=\"column\" value=\"", htmlspecialchars($_REQUEST['column']), "\" />\n";
 				echo "<input type=\"hidden\" name=\"olddefault\" value=\"", htmlspecialchars($_REQUEST['olddefault']), "\" />\n";
-				if ($column->f['attnotnull']) echo "<input type=\"hidden\" name=\"oldnotnull\" value=\"on\" />\n";
-				echo "<input type=\"hidden\" name=\"oldtype\" value=\"", htmlspecialchars($data->formatType($column->f['type'], $column->f['atttypmod'])), "\" />\n";
+				if ($column->fields['attnotnull']) echo "<input type=\"hidden\" name=\"oldnotnull\" value=\"on\" />\n";
+				echo "<input type=\"hidden\" name=\"oldtype\" value=\"", htmlspecialchars($data->formatType($column->fields['type'], $column->fields['atttypmod'])), "\" />\n";
 				// Add hidden variables to suppress error notices if we don't support altering column type
 				if (!$data->hasAlterColumnType()) {
 					echo "<input type=\"hidden\" name=\"type\" value=\"", htmlspecialchars($_REQUEST['type']), "\" />\n";				
@@ -139,18 +138,16 @@
 				echo "<input type=\"submit\" value=\"{$lang['stralter']}\" />\n";
 				echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 				echo "</form>\n";
-								
+				echo "<script type=\"text/javascript\">predefined_lengths = new Array(". implode(",",$escaped_predef_types) .");checkLengths(document.getElementById('type').value,'');</script>\n";		
 				break;
 			case 2:
-				global $data, $lang;
-
 				// Check inputs
 				if (trim($_REQUEST['field']) == '') {
 					$_REQUEST['stage'] = 1;
-					doProperties($lang['strcolneedsname']);
+					doAlter($lang['strcolneedsname']);
 					return;
 				}
-
+				if (!isset($_REQUEST['length'])) $_REQUEST['length'] = '';
 				$status = $data->alterColumn($_REQUEST['table'], $_REQUEST['column'], $_REQUEST['field'], 
 							     isset($_REQUEST['notnull']), isset($_REQUEST['oldnotnull']), 
 							     $_REQUEST['default'], $_REQUEST['olddefault'],
@@ -158,14 +155,14 @@
 							     $_REQUEST['comment']);
 				if ($status == 0) {
 					if ($_REQUEST['column'] != $_REQUEST['field']) {
-						$_REQUEST['column']=$_REQUEST['field'];
+						$_REQUEST['column'] = $_REQUEST['field'];
 						$_reload_browser = true;
 					}
 					doDefault($lang['strcolumnaltered']);
 				}
 				else {
 					$_REQUEST['stage'] = 1;
-					doProperties($lang['strcolumnalteredbad']);
+					doAlter($lang['strcolumnalteredbad']);
 					return;
 				}
 				break;
@@ -183,15 +180,15 @@
 
 		function attPre(&$rowdata) {
 			global $data;
-			$rowdata->f['+type'] = $data->formatType($rowdata->f['type'], $rowdata->f['atttypmod']);
+			$rowdata->fields['+type'] = $data->formatType($rowdata->fields['type'], $rowdata->fields['atttypmod']);
 		}
 		
 		if (empty($_REQUEST['column']))
 			$msg.= "<br/>{$lang['strnoobjects']}";
 		
 			$misc->printTrail('column');
-			$misc->printTitle($lang['strcolprop']);
-			#$misc->printTabs('column','properties');
+			//$misc->printTitle($lang['strcolprop']);
+			$misc->printTabs('column','properties');
 			$misc->printMsg($msg);
 
 		if (! empty($_REQUEST['column'])) {
@@ -201,30 +198,30 @@
 			$attrs = $data->getTableAttributes($tableName, $_REQUEST['column']);
 
 			// Show comment if any
-			if ($attrs->f['comment'] !== null)
-				echo "<p class=\"comment\">", $misc->printVal($attrs->f['comment']), "</p>\n";
+			if ($attrs->fields['comment'] !== null)
+				echo "<p class=\"comment\">", $misc->printVal($attrs->fields['comment']), "</p>\n";
 
 			$column = array(
 				'column' => array(
 					'title' => $lang['strcolumn'],
-					'field' => 'attname',
+					'field' => field('attname'),
 				),
 				'type' => array(
 					'title' => $lang['strtype'],
-					'field' => '+type',
+					'field' => field('+type'),
 				)
 			);
 		
 			if ($isTable) {
 				$column['notnull'] = array(
 					'title' => $lang['strnotnull'],
-					'field' => 'attnotnull',
+					'field' => field('attnotnull'),
 					'type'  => 'bool',
 					'params'=> array('true' => 'NOT NULL', 'false' => '')
 				);
 				$column['default'] = array(
 					'title' => $lang['strdefault'],
-					'field' => 'adsrc'
+					'field' => field('adsrc'),
 				);
 			}
 
@@ -233,29 +230,41 @@
 
 			echo "<br />\n";
 
-			echo "<ul>\n";
+			echo "<ul class=\"navlink\">\n";
+			$f_attname = $_REQUEST['column'];
+			$f_table = $tableName;
+			$f_schema = $data->_schema;
+			$data->fieldClean($f_attname);
+			$data->fieldClean($f_table);
+			$data->fieldClean($f_schema);
+			$query_url = urlencode("SELECT \"{$f_attname}\", count(*) AS \"count\" FROM \"{$f_schema}\".\"{$f_table}\" GROUP BY \"{$f_attname}\" ORDER BY \"{$f_attname}\"") ;
+
 			if ($isTable) {
-				$return_url = urlencode("colproperties.php?{$misc->href}&amp;table=$tableName&amp;column={$_REQUEST['column']}");
+				$return_url = urlencode("colproperties.php?{$misc->href}&amp;table=". urlencode($tableName)
+					."&amp;column=". urlencode($_REQUEST['column']));
 
 				/* Browse link */
-				echo "\t<li><a href=\"display.php?{$misc->href}&amp;table=", urlencode($tableName), "&amp;subject=column&amp;column=",
-					urlencode($_REQUEST['column']), "&amp;return_url={$return_url}&amp;return_desc=", urlencode($lang['strback']), "&amp;query=", 
-					urlencode("SELECT {$_REQUEST['column']}, count(*) AS \"count\" FROM $tableName GROUP BY {$_REQUEST['column']} ORDER BY {$_REQUEST['column']}") , "\">{$lang['strbrowse']}</a></li>\n";
+				/* FIXME browsing a col should somehow be a action so we don't
+				 * send an ugly SQL in the URL */
+				echo "\t<li><a href=\"display.php?{$misc->href}&amp;subject=column&amp;table=",
+					urlencode($_REQUEST['table']),
+					"&amp;column=", urlencode($_REQUEST['column']),
+					"&amp;return_url={$return_url}&amp;return_desc=", urlencode($lang['strback']), 
+					"&amp;query={$query_url}\">{$lang['strbrowse']}</a></li>\n";
 
 				/* Edit link */
-				echo "\t<li><a href=\"colproperties.php?action=properties&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),
+				echo "\t<li><a href=\"colproperties.php?action=properties&amp;{$misc->href}&amp;table=", urlencode($tableName),
 				    "&amp;column=", urlencode($_REQUEST['column']) . "\">{$lang['stralter']}</a></li>\n";
 				
-				/* Delete link */
-				if ($data->hasDropColumn())
-					echo "\t<li><a href=\"tblproperties.php?action=confirm_drop&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),
+					echo "\t<li><a href=\"tblproperties.php?action=confirm_drop&amp;{$misc->href}&amp;table=", urlencode($tableName),
 						"&amp;column=" . urlencode($_REQUEST['column']) . "\">{$lang['strdrop']}</a></li>\n";
 			} else {
-				$return_url = urlencode("colproperties.php?{$misc->href}&amp;view=$tableName&amp;column={$_REQUEST['column']}");
+				$return_url = urlencode("colproperties.php?{$misc->href}&amp;view=". urlencode($tableName)
+					."&amp;column=". urlencode($_REQUEST['column']));
 				/* Browse link */
-				echo "\t<li><a href=\"display.php?{$misc->href}&amp;view=", urlencode($tableName), "&amp;subject=column&amp;column=",
-					urlencode($_REQUEST['column']), "&amp;return_url={$return_url}&amp;return_desc=", urlencode($lang['strback']), "&amp;query=",
-					urlencode("SELECT {$_REQUEST['column']}, count(*) AS \"count\" FROM $tableName GROUP BY {$_REQUEST['column']} ORDER BY {$_REQUEST['column']}") , "\">{$lang['strbrowse']}</a></li>\n";
+				echo "\t<li><a href=\"display.php?{$misc->href}&amp;subject=column&amp;column=",
+					urlencode($_REQUEST['column']), "&amp;return_url={$return_url}&amp;return_desc=", urlencode($lang['strback']),
+					"&amp;query={$query_url}\">{$lang['strbrowse']}</a></li>\n";
 			}
 
 			echo "</ul>\n";
@@ -271,7 +280,7 @@
 		switch ($action) {
 			case 'properties':
 				if (isset($_POST['cancel'])) doDefault();
-				else doProperties();
+				else doAlter();
 				break;
 			default:
 				doDefault();
