@@ -344,7 +344,6 @@
 	$lang['strcachevalue'] = 'Cache Hodnota';
 	$lang['strlogcount'] = 'Log Súčet';
 	$lang['striscycled'] = 'Je Cycled?';
-	$lang['striscalled'] = 'Je Called?';
 	$lang['strsequenceneedsname'] = 'Musíš zadať názov pre tvoju sekvenciu.';
 	$lang['strsequencecreated'] = 'Sekvencia vytvorená.';
 	$lang['strsequencecreatedbad'] = 'Sekvencia nebola vytvorená.';
@@ -757,7 +756,7 @@ $lang['strsubscriptions']  =  'Subscriptions';
 $lang['strnosubscriptions']  =  'No subscriptions found.';
 
 	// Miscellaneous
-	$lang['strtopbar']  =  '%s beží na %s:%s -- si prihlásený ako "%s", %s';
+	$lang['strtopbar']  =  '%s beží na %s:%s -- si prihlásený ako "%s"';
 	$lang['strtimefmt']  =  'jS M, Y g:iA';
 	$lang['strhelp']  =  'Pomoc';
 	$lang['strhelpicon']  =  '?';
