@@ -4,7 +4,7 @@
 	 * Turkish language file for phpPgAdmin.  Use this as a basis
 	 * for new translations.
 	 *
-	 * $Id: turkish.php,v 1.14 2005/11/14 04:54:26 chriskl Exp $
+	 * $Id: turkish.php,v 1.15 2007/04/24 11:42:07 soranzo Exp $
 	 */
 
 	// Language and character set
@@ -345,7 +345,6 @@ $lang['strcannotdumponwindows']  =  'Dumping of complex table and schema names o
 	$lang['strcachevalue'] = 'Cache Deeri';
 	$lang['strlogcount'] = 'Log Count';
 	$lang['striscycled'] = 'Is Cycled?';
-	$lang['striscalled'] = 'Is Called?';
 	$lang['strsequenceneedsname'] = 'Sequence iin bir ad belirtmelisiniz.';
 	$lang['strsequencecreated'] = 'Sequence yaratld.';
 	$lang['strsequencecreatedbad'] = 'Sequence yaratma ilemi baarsz oldu.'; 
@@ -752,7 +751,7 @@ $lang['strsequenceremovedfromrepsetbad']  =  'Failed to remove sequence from rep
 	$lang['strnosubscriptions']  =  'yelik bulunamad.';
 
 	// Miscellaneous
-	$lang['strtopbar']  =  '%s, %s:%s zerinde alyor-- "%s", %s kullancs ile sisteme giri yaptnz.';
+	$lang['strtopbar']  =  '%s, %s:%s zerinde alyor-- "%s" kullancs ile sisteme giri yaptnz.';
         $lang['strtimefmt']  =  'jS M, Y g:iA';
         $lang['strhelp']  =  'Yardm';
 	$lang['strhelpicon'] = '?';
