@@ -593,7 +593,7 @@
         $lang['strrows2'] = '';
 
         // Miscellaneous
-        $lang['strtopbar'] = '%s դ  %s:%s --  Ť  "%s", %s';
+        $lang['strtopbar'] = '%s դ  %s:%s --  Ť  "%s"';
         $lang['strtimefmt'] = ' j-m-Y  g:i';
         $lang['strhelp'] = '';
 
