@@ -3,7 +3,7 @@
 	/**
 	 * List views in a database
 	 *
-	 * $Id: viewproperties.php,v 1.21.2.1 2007/05/28 17:21:57 ioguix Exp $
+	 * $Id: viewproperties.php,v 1.34 2007/12/11 14:17:17 ioguix Exp $
 	 */
 
 	// Include application functions
@@ -29,7 +29,7 @@
 	 */
 	function doEdit($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
 		$misc->printTrail('view');
 		$misc->printTitle($lang['stredit'],'pg.view.alter');
@@ -40,17 +40,17 @@
 		if ($viewdata->recordCount() > 0) {
 			
 			if (!isset($_POST['formDefinition'])) {
-				$_POST['formDefinition'] = $viewdata->f['vwdefinition'];
-				$_POST['formComment'] = $viewdata->f['relcomment'];
+				$_POST['formDefinition'] = $viewdata->fields['vwdefinition'];
+				$_POST['formComment'] = $viewdata->fields['relcomment'];
 			}
 			
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
-			echo "<table width=\"100%\">\n";
+			echo "<form action=\"viewproperties.php\" method=\"post\">\n";
+			echo "<table style=\"width: 100%\">\n";
 			echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strdefinition']}</th>\n";
-			echo "\t\t<td class=\"data1\"><textarea style=\"width: 100%;\" rows=\"20\" cols=\"50\" name=\"formDefinition\" wrap=\"virtual\">", 
+			echo "\t\t<td class=\"data1\"><textarea style=\"width: 100%;\" rows=\"20\" cols=\"50\" name=\"formDefinition\">", 
 				htmlspecialchars($_POST['formDefinition']), "</textarea></td>\n\t</tr>\n";
 			echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strcomment']}</th>\n";
-			echo "\t\t<td class=\"data1\"><textarea rows=\"3\" cols=\"32\" name=\"formComment\" wrap=\"virtual\">", 
+			echo "\t\t<td class=\"data1\"><textarea rows=\"3\" cols=\"32\" name=\"formComment\">", 
 				htmlspecialchars($_POST['formComment']), "</textarea></td>\n\t</tr>\n";
 			echo "</table>\n";
 			echo "<p><input type=\"hidden\" name=\"action\" value=\"save_edit\" />\n";
@@ -72,7 +72,7 @@
 	 */
 	function doExport($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		$misc->printTrail('view');
 		$misc->printTabs('view','export');
@@ -129,7 +129,7 @@
 	 */
 	function doDefinition($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 	
 		// Get view
 		$vdata = $data->getView($_REQUEST['view']);
@@ -140,17 +140,17 @@
 		
 		if ($vdata->recordCount() > 0) {
 			// Show comment if any
-			if ($vdata->f['relcomment'] !== null)
-				echo "<p class=\"comment\">", $misc->printVal($vdata->f['relcomment']), "</p>\n";
+			if ($vdata->fields['relcomment'] !== null)
+				echo "<p class=\"comment\">", $misc->printVal($vdata->fields['relcomment']), "</p>\n";
 
-			echo "<table width=\"100%\">\n";
+			echo "<table style=\"width: 100%\">\n";
 			echo "<tr><th class=\"data\">{$lang['strdefinition']}</th></tr>\n";
-			echo "<tr><td class=\"data1\">", $misc->printVal($vdata->f['vwdefinition']), "</td></tr>\n";
+			echo "<tr><td class=\"data1\">", $misc->printVal($vdata->fields['vwdefinition']), "</td></tr>\n";
 			echo "</table>\n";
 		}
 		else echo "<p>{$lang['strnodata']}</p>\n";
 		
-		echo "<p><a class=\"navlink\" href=\"{$PHP_SELF}?action=edit&amp;{$misc->href}&amp;view=", 
+		echo "<p><a class=\"navlink\" href=\"viewproperties.php?action=edit&amp;{$misc->href}&amp;view=", 
 			urlencode($_REQUEST['view']), "\">{$lang['stralter']}</a></p>\n";
 	}
 
@@ -159,7 +159,7 @@
 	 */
 	function doProperties($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		if (!isset($_REQUEST['stage'])) $_REQUEST['stage'] = 1;
 
@@ -168,10 +168,10 @@
 				global $lang;
 
 				$misc->printTrail('column');
-				$misc->printTitle($lang['straltercolumn'],'pg.column.alter'); 
+				$misc->printTitle($lang['stralter'],'pg.column.alter'); 
 				$misc->printMsg($msg);
 
-				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+				echo "<form action=\"viewproperties.php\" method=\"post\">\n";
 
 				// Output view header
 				echo "<table>\n";
@@ -181,20 +181,15 @@
 				$column = $data->getTableAttributes($_REQUEST['view'], $_REQUEST['column']);
 
 				if (!isset($_REQUEST['default'])) {
-					$_REQUEST['field'] = $column->f['attname'];
-					$_REQUEST['default'] = $_REQUEST['olddefault'] = $column->f['adsrc'];
-					$_REQUEST['comment'] = $column->f['comment'];
+					$_REQUEST['field'] = $column->fields['attname'];
+					$_REQUEST['default'] = $_REQUEST['olddefault'] = $column->fields['adsrc'];
+					$_REQUEST['comment'] = $column->fields['comment'];
 				}
 
-				// If name of view column is editable, make it a field
-				if ($data->hasViewColumnRename()) {
-					echo "<tr><td><input name=\"field\" size=\"32\" value=\"",
-						htmlspecialchars($_REQUEST['field']), "\" /></td>";
-				}
-				else {
-					echo "<tr><td>", htmlspecialchars($column->f['attname']), "</td>";					
-				}
-				echo "<td>", $misc->printVal($data->formatType($column->f['type'], $column->f['atttypmod'])), "</td>";
+				echo "<tr><td><input name=\"field\" size=\"32\" value=\"",
+					htmlspecialchars($_REQUEST['field']), "\" /></td>";
+				
+				echo "<td>", $misc->printVal($data->formatType($column->fields['type'], $column->fields['atttypmod'])), "</td>";
 				echo "<td><input name=\"default\" size=\"20\" value=\"", 
 					htmlspecialchars($_REQUEST['default']), "\" /></td>";
 				echo "<td><input name=\"comment\" size=\"32\" value=\"", 
@@ -216,15 +211,12 @@
 				global $data, $lang;
 
 				// Check inputs
-				if ($data->hasViewColumnRename() && trim($_REQUEST['field']) == '') {
+				if (trim($_REQUEST['field']) == '') {
 					$_REQUEST['stage'] = 1;
 					doProperties($lang['strcolneedsname']);
 					return;
 				}
 				
-				// If we aren't able to rename view columns, set new name to equal old name always
-				if (!$data->hasViewColumnRename()) $_REQUEST['field'] = $_REQUEST['column'];
-				
 				// Alter the view column
 				$status = $data->alterColumn($_REQUEST['view'], $_REQUEST['column'], $_REQUEST['field'], 
 							     false, false, $_REQUEST['default'], $_REQUEST['olddefault'],
@@ -242,6 +234,103 @@
 		}
 	}
 
+	function doAlter($confirm = false, $msg = '') {
+		if ($confirm) {
+			global $data, $misc, $lang;
+
+			$misc->printTrail('view');
+			$misc->printTitle($lang['stralter'], 'pg.view.alter');
+			$misc->printMsg($msg);
+
+			// Fetch view info
+			$view = $data->getView($_REQUEST['view']);
+
+			if ($view->recordCount() > 0) {
+				if (!isset($_POST['name'])) $_POST['name'] = $view->fields['relname'];
+	            if (!isset($_POST['owner'])) $_POST['owner'] = $view->fields['relowner'];
+	            if (!isset($_POST['newschema'])) $_POST['newschema'] = $view->fields['nspname'];
+				if (!isset($_POST['comment'])) $_POST['comment'] = $view->fields['relcomment'];
+
+				echo "<form action=\"viewproperties.php\" method=\"post\">\n";
+				echo "<table>\n";
+	            echo "<tr><th class=\"data left required\">{$lang['strname']}</th>\n";
+				echo "<td class=\"data1\">";
+				echo "<input name=\"name\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"",
+					htmlspecialchars($_POST['name']), "\" /></td></tr>\n";
+
+				$server_info = $misc->getServerInfo();
+				if ($data->isSuperUser($server_info['username'])) {
+
+					// Fetch all users
+					$users = $data->getUsers();
+
+					echo "<tr><th class=\"data left required\">{$lang['strowner']}</th>\n";
+					echo "<td class=\"data1\"><select name=\"owner\">";
+					while (!$users->EOF) {
+						$uname = $users->fields['usename'];
+						echo "<option value=\"", htmlspecialchars($uname), "\"",
+						($uname == $_POST['owner']) ? ' selected="selected"' : '', ">", htmlspecialchars($uname), "</option>\n";
+						$users->moveNext();
+					}
+					echo "</select></td></tr>\n";
+				}
+
+				if ($data->hasAlterTableSchema()) {
+					$schemas = $data->getSchemas();
+					echo "<tr><th class=\"data left required\">{$lang['strschema']}</th>\n";
+					echo "<td class=\"data1\"><select name=\"newschema\">";
+					while (!$schemas->EOF) {
+						$schema = $schemas->fields['nspname'];
+						echo "<option value=\"", htmlspecialchars($schema), "\"",
+							($schema == $_POST['newschema']) ? ' selected="selected"' : '', ">", htmlspecialchars($schema), "</option>\n";
+						$schemas->moveNext();
+					}
+					echo "</select></td></tr>\n";
+				}
+				
+				echo "<tr><th class=\"data left\">{$lang['strcomment']}</th>\n";
+				echo "<td class=\"data1\">";
+				echo "<textarea rows=\"3\" cols=\"32\" name=\"comment\">",
+	                htmlspecialchars($_POST['comment']), "</textarea></td></tr>\n";
+				echo "</table>\n";
+				echo "<input type=\"hidden\" name=\"action\" value=\"alter\" />\n";
+				echo "<input type=\"hidden\" name=\"view\" value=\"", htmlspecialchars($_REQUEST['view']), "\" />\n";
+				echo $misc->form;
+				echo "<p><input type=\"submit\" name=\"alter\" value=\"{$lang['stralter']}\" />\n";
+	            echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
+				echo "</form>\n";
+			}
+			else echo "<p>{$lang['strnodata']}</p>\n";
+		}
+		else{
+			global $data, $lang, $_reload_browser, $misc;
+
+			// For databases that don't allow owner change
+	        if (!isset($_POST['owner'])) $_POST['owner'] = '';
+	        if (!isset($_POST['newschema'])) $_POST['newschema'] = null;
+
+			$status = $data->alterView($_POST['view'], $_POST['name'], $_POST['owner'], $_POST['newschema'], $_POST['comment']);
+			if ($status == 0) {
+				// If view has been renamed, need to change to the new name and
+				// reload the browser frame.
+				if ($_POST['view'] != $_POST['name']) {
+					// Jump them to the new view name
+					$_REQUEST['view'] = $_POST['name'];
+	                // Force a browser reload
+					$_reload_browser = true;
+				}
+				// If schema has changed, need to change to the new schema and reload the browser
+				if (!empty($_POST['newschema']) && ($_POST['newschema'] != $data->_schema)) {
+					// Jump them to the new sequence schema
+					$misc->setCurrentSchema($_POST['newschema']);
+					$_reload_browser = true;
+				}
+				doDefault($lang['strviewaltered']);
+			}
+			else doAlter(true, $lang['strviewalteredbad']);
+		}
+	}
+
 	function doTree () {
 		global $misc, $data;
 
@@ -263,8 +352,8 @@
 							array(
 								'view'     => $_REQUEST['view'],
 								'column'    => field('attname'),
-								'query'     => prepareSQL(
-									"SELECT %column%, count(*) AS \"count\" FROM %view% GROUP BY %column% ORDER BY %column%",
+								'query'     => replace(
+									'SELECT "%column%", count(*) AS "count" FROM %view% GROUP BY "%column%" ORDER BY "%column%"',
 									array (
 										'%column%' => field('attname'),
 										'%view%' => $_REQUEST['view']
@@ -287,11 +376,11 @@
 	 */
 	function doDefault($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
 		function attPre(&$rowdata) {
 			global $data;
-			$rowdata->f['+type'] = $data->formatType($rowdata->f['type'], $rowdata->f['atttypmod']);
+			$rowdata->fields['+type'] = $data->formatType($rowdata->fields['type'], $rowdata->fields['atttypmod']);
 		}
 		
 		$misc->printTrail('view');
@@ -304,35 +393,35 @@
 		$attrs = $data->getTableAttributes($_REQUEST['view']);		
 
 		// Show comment if any
-		if ($vdata->f['relcomment'] !== null)
-			echo "<p class=\"comment\">", $misc->printVal($vdata->f['relcomment']), "</p>\n";
+		if ($vdata->fields['relcomment'] !== null)
+			echo "<p class=\"comment\">", $misc->printVal($vdata->fields['relcomment']), "</p>\n";
 
 		$columns = array(
 			'column' => array(
 				'title' => $lang['strcolumn'],
-				'field' => 'attname',
+				'field' => field('attname'),
 			),
 			'type' => array(
 				'title' => $lang['strtype'],
-				'field' => '+type',
+				'field' => field('+type'),
 			),
 			'default' => array(
 				'title' => $lang['strdefault'],
-				'field' => 'adsrc',
+				'field' => field('adsrc'),
 			),
 			'actions' => array(
 				'title' => $lang['stractions'],
 			),
 			'comment' => array(
 				'title' => $lang['strcomment'],
-				'field' => 'comment',
+				'field' => field('comment'),
 			),
 		);
 		
 		$actions = array(
 			'alter' => array(
 				'title' => $lang['stralter'],
-				'url'   => "{$PHP_SELF}?action=properties&amp;{$misc->href}&amp;view=".urlencode($_REQUEST['view'])."&amp;",
+				'url'   => "viewproperties.php?action=properties&amp;{$misc->href}&amp;view=".urlencode($_REQUEST['view'])."&amp;",
 				'vars'  => array('column' => 'attname'),
 			),
 		);
@@ -341,12 +430,13 @@
 	
 		echo "<br />\n";
 
-		echo "<ul>\n";
+		echo "<ul class=\"navlink\">\n";
 		$return_url = urlencode("viewproperties.php?{$misc->href}&amp;view=" . urlencode($_REQUEST['view']));
 		echo "\t<li><a href=\"display.php?{$misc->href}&amp;view=", urlencode($_REQUEST['view']), "&amp;subject=view&amp;return_url={$return_url}&amp;return_desc=",
 			urlencode($lang['strback']), "\">{$lang['strbrowse']}</a></li>\n";
 		echo "\t<li><a href=\"views.php?action=confselectrows&amp;{$misc->href}&amp;view=", urlencode($_REQUEST['view']),"\">{$lang['strselect']}</a></li>\n";
 		echo "\t<li><a href=\"views.php?action=confirm_drop&amp;{$misc->href}&amp;view=", urlencode($_REQUEST['view']),"\">{$lang['strdrop']}</a></li>\n";
+		echo "\t<li><a href=\"viewproperties.php?action=confirm_alter&amp;{$misc->href}&amp;view=", urlencode($_REQUEST['view']),"\">{$lang['stralter']}</a></li>\n";
 		echo "</ul>\n";
 	}
 
@@ -371,6 +461,13 @@
 			if (isset($_POST['cancel'])) doDefault();
 			else doProperties();
 			break;
+		case 'alter':
+			if (isset($_POST['alter'])) doAlter(false);
+			else doDefault();
+			break;
+		case 'confirm_alter':
+			doAlter(true);
+			break;
 		case 'drop':
 			if (isset($_POST['drop'])) doDrop(false);
 			else doDefault();
